## ----style, echo = FALSE, results = 'asis'------------------------------------
BiocStyle::markdown()

## -----------------------------------------------------------------------------
library(RNASeqHelper)

## -----------------------------------------------------------------------------
num_genes <- 10000
mean_sd <- list(c(10, 10), c(10, 10), c(10, 10),
                c(20, 20), c(20, 20), c(30, 30),
                c(90, 90), c(90, 90), c(90, 90))

mat <- as.matrix(
    do.call(cbind,
        lapply(seq_along(mean_sd), function(i) {
    x <- mean_sd[[i]]
    tab <- matrix(as.integer(rnorm(num_genes, x[[1]], x[[2]])), ncol=1,
                dimnames=list(paste0("G", 1:num_genes), paste0("S", i)))
    tab <- tab - min(tab) ## no zeroes
    return(tab)
})))

phenotype_data <- data.frame(sample = colnames(mat),
            condition = c(rep("green", 3), rep("red", 3), rep("blue", 3)),
            time = c(5, 5, 15, 10, 10, 15, 5, 10, 15))

message("First 6 lines of the matrix")
head(mat)
message("Phenotype Data")
phenotype_data

## -----------------------------------------------------------------------------
gois_list <- source(system.file("extdata", "gois.R", package="RNASeqHelper"),
                    local=TRUE)
gois_list

## -----------------------------------------------------------------------------
gois_list <- list(apple = paste0("G", 100:105),
                banana = paste0("G", 810:819),
                carrot = paste0("G", 256:260))
gois_list

## -----------------------------------------------------------------------------
keep_genes <- high_quality_genes(mat, min_occur=3, min_detect=2,
                                out_dir=file.path(tempdir(), "0_genes"))

## -----------------------------------------------------------------------------
keep_genes <- high_quality_genes(mat, min_occur=8, min_detect=20,
                                out_dir=file.path(tempdir(), "0_genes"))

## -----------------------------------------------------------------------------
res <- run_deseq(mat, keep_genes, phenotype_data,
        out_dir = file.path(tempdir(), "1_matrices_and_deseq"))

## -----------------------------------------------------------------------------
pairwise_hmap_volcano(res[["ddsObj"]],
                    numer = "green", denom = "blue",
                    transformed_counts = assay(res[["vFalse"]]),
                    top_ngenes_tocluster = 2000,
                    top_ngenes_tohighlight = 25,
                    score_thresh = c(0.5, 0.9),
                    genes_of_interest = gois_list,
                    kmeans_list = c(2, 5),
                    out_dirprefix=file.path(tempdir(), "2_heatmaps"))


## -----------------------------------------------------------------------------
rnaseqhelper(mat, phenotype_data, numer = "green", denom = "blue",
            out_dir=file.path(tempdir(), "second_analysis"),
            keep_params = list(min_occur=8, min_detect=20),
            heat_params = list(top_ngenes_tocluster = 1000,
                                top_ngenes_tohighlight = 25,
                                score_thresh = 0.9,
                                genes_of_interest = gois_list[["apple"]],
                                kmeans_list = 2))


## -----------------------------------------------------------------------------
sessionInfo()

